#
# lxc: linux Container library
#
# (C) Copyright IBM Corp. 2007, 2008
#
# Authors:
# Daniel Lezcano <daniel.lezcano at free.fr>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#

%global with_python %{?_with_python: 1} %{?!_with_python: 0}
%global with_lua %{?_with_lua: 1} %{?!_with_lua: 0}

# Set with_systemd on distros that use it, so we can install the service
# file, otherwise the sysvinit script will be installed
%if 0%{?fedora} >= 14 || 0%{?rhel} >= 7 || 0%{?suse_version} >= 1210
%global with_systemd 1
%define init_script systemd
BuildRequires: systemd-units
%else
%global with_systemd 0
%define init_script sysvinit
%endif

# RPM needs alpha/beta/rc in Release: not Version: to ensure smooth
# package upgrades from alpha->beta->rc->release. For more info see:
# http://fedoraproject.org/wiki/Packaging%3aNamingGuidelines#NonNumericRelease
%if "x" != "x"
%global beta_rel @LXC_VERSION_BETA@
%global beta_dot .%{beta_rel}
%else
%global norm_rel 2.0.8
%endif

Name: lxc
Version: 1.0.7
Release: %{?beta_rel:0.1.%{beta_rel}}%{?!beta_rel:%{norm_rel}}%{?dist}
URL: http://linuxcontainers.org
Source: http://linuxcontainers.org/downloads/%{name}-%{version}%{?beta_dot}.tar.gz
Summary: Linux Containers userspace tools
Group: Applications/System
License: LGPLv2+
BuildRoot: %{_tmppath}/%{name}-%{version}-build
Requires: %{name}-libs = %{version}-%{release}
Requires: libcap libvirt openssl rsync
BuildRequires: libcap libcap-devel libselinux-devel docbook-utils automake autoconf

Patch0001: 0010-lxc-oracle-allow-installing-from-arbitrary-yum-repo.patch
Patch0002: 0020-lxc-oracle-update-to-support-OL7.patch
Patch0003: 0030-lxc-oracle-only-create-media-repo-when-baseurl-is-sp.patch
Patch0004: 0040-lxc-oracle-mount-cgroup-mixed.patch
Patch0005: 0050-snapshots-move-snapshot-directory.patch
Patch0006: 0060-lxc-oracle-introducing-privileged-flag-and-including.patch
Patch0007: 0070-Introducing-privileged-configuration-file.patch
Patch0008: 0080-Dynamic-RT-management-hook-script.patch
Patch0009: 0090-CVE-2015-1331-lxclock-use-run-lxc-lock-rather-than-r.patch
Patch0010: 0100-CVE-2015-1334-Don-t-use-the-container-s-proc-during-.patch
Patch0011: 0101-Fix-templates-creation-when-using-OVM-template-as-ro.patch

%if %{with_python}
Requires: python3
BuildRequires: python3-devel
%endif

%description
Containers are insulated areas inside a system, which have their own namespace
for filesystem, network, PID, IPC, CPU and memory allocation and which can be
created using the Control Group and Namespace features included in the Linux
kernel.

This package provides the lxc-* tools, which can be used to start a single
daemon in a container, or to boot an entire "containerized" system, and to
manage and debug your containers.

%package	libs
Summary:	Shared library files for %{name}
Group:		System Environment/Libraries
%description	libs
The %{name}-libs package contains libraries for running %{name} applications.

%package	devel
Summary:	Development library for %{name}
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}, pkgconfig
%description	devel
The %{name}-devel package contains header files and library needed for
development of the Linux containers.

%if %{with_lua}
%package	lua
Summary:	Lua bindings for %{name}
Group:		System Environment/Libraries
Requires:	lua-filesystem lua-alt-getopt
BuildRequires:	lua-devel
%description	lua
The %{name}-lua package contains %{name} bindings for lua.
%endif

%prep
%setup -q -n %{name}-%{version}%{?beta_dot}
%patch0001 -p1
%patch0002 -p1
%patch0003 -p1
%patch0004 -p1
%patch0005 -p1
%patch0006 -p1
%patch0007 -p1
%patch0008 -p1
%patch0009 -p1
%patch0010 -p1
%patch0011 -p1
%build
./autogen.sh
PATH=$PATH:/usr/sbin:/sbin %configure $args \
  --disable-apparmor \
  --enable-configpath-log \
  --with-config-path=/container \
%if %{with_lua}
  --enable-lua \
%else
  --disable-lua \
%endif
%if %{with_python}
  --enable-python \
%else
  --disable-python \
%endif
  --disable-rpath \
  --with-init-script=%{init_script}
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
find %{buildroot} -type f -name '*.la' -exec rm -f {} ';'

%clean
rm -rf %{buildroot}

%post
mkdir -p /container
rm -f /run/lxc/lock/container/*

%post   libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/*
%{_mandir}/man1/lxc*
%{_mandir}/man5/lxc*
%{_mandir}/man7/lxc*
%{_datadir}/doc/*
%{_datadir}/lxc/*
%{_sysconfdir}/bash_completion.d
%config(noreplace) %{_sysconfdir}/lxc/*

%if %{with_systemd}
%{_unitdir}/lxc.service
%else
%{_sysconfdir}/rc.d/init.d/lxc
%endif

%files libs
%defattr(-,root,root)
%{_sbindir}/*
%{_libdir}/*.so.*
%{_libdir}/%{name}
%if %{with_python}
%{_libdir}/python*
%endif
%{_localstatedir}/*
%{_libexecdir}/%{name}
%attr(4111,root,root) %{_libexecdir}/%{name}/lxc-user-nic
%if %{with_systemd}
%attr(555,root,root) %{_libexecdir}/%{name}/lxc-devsetup
%attr(555,root,root) %{_libexecdir}/%{name}/lxc-autostart-helper
%endif

%if %{with_python}
%{_libdir}/python3.3/site-packages/_lxc*
%{_libdir}/python3.3/site-packages/lxc/*
%endif

%if %{with_lua}
%files lua
%defattr(-,root,root)
%{_datadir}/lua
%{_libdir}/lua
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*

%changelog
* Thu Aug 13 2015 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.0.7-2.0.8
- [Orabug 21603129] mount /proc/sys/kernel/msgmni as r/w in container
- [Orabug 21418260] using OL6/7 OVM templates to create container
- Includes the lxc-lib dependency when upgrading LXC. 

* Thu Jul 30 2015 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.0.7-2.0.7
- [Orabug 21533491] CVE-2015-1334: Don't use the container's /proc during
  attach

* Wed Jul 29 2015 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.0.7-2.0.6
- [Orabug 21526922] CVE-2015-1331: LXCLOCK: USE /RUN/LXC/LOCK RATHER THAN
  /RUN/LOCK/LXC

* Mon Jun 22 2015 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.0.7-2.0.5
- [Orabug 21267882] Make some of the global parameters as read-only inside
  the container.

* Mon Jun 15 2015 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.0.7-2.0.4
- [Orabug 21233392] Oracle Linux Container enhancement. We are introducing
  3 enhancements (introducing --privileged flag for lxc-oracle, new
  configuration file for more privileged lxc use case and dynamic RT
  management script).

* Tue Feb 10 2015 Dwight Engen <dwight.engen@oracle.com> - 1.0.7-2.0.3
- [Orabug 20465908] Go ahead and backport upstream commit 18aa217b.
  The symlink workaround was too hackish. With this change, the lock
  file names in /run/lock/lxc/container change from <name> to .<name>
  but snapshots need <name> to now be a directory so we remove any
  old lock files that might be there in %post.

* Wed Feb 04 2015 Dwight Engen <dwight.engen@oracle.com> - 1.0.7-2.0.2
- [Orabug 20465908] Introduce a workaround for creating btrfs snapshots
  by symlinking /containersnaps to a dir in /container. Snapshots will
  thus be created in the same btrfs. The real fix is upstream commit
  18aa217b, but that is too invasive to backport to 1.0.x.

* Mon Dec 08 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.7-2.0.1
- update to upstream 1.0.7

* Wed Oct 15 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.6-2.0.1
- update to upstream 1.0.6
- explicitly mention lxc-autostart-helper in %files to match upstream

* Wed Jul 23 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.5-2.0.2
- add libselinux-devel to BuildRequires so that lxc detects SELinux
  in the build environment and builds support for it

* Tue Jul 15 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.5-2.0.1
- update to upstream 1.0.5
- use upstream patch for cgroup:mixed and yum channel name

* Thu Jul 03 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.4-2.0.3
- [Orabug 19152320] Mount cgroup:mixed to prevent systemd from moving
  out of lxc setup cgroup

* Mon Jun 23 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.4-2.0.2
- update channel name to ol7_u0_base for OL7 public-yum

* Fri Jun 13 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.4-2.0.1
- update to upstream 1.0.4

* Thu Apr 10 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.3-2.0.2
- [Orabug 18526838] add back in libcap and libvirt Requires which were
  inadvertantly dropped when updating the .spec file to upstream 1.0

* Wed Apr 09 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.3-2.0.1
- update to upstream 1.0.3
- include patch for installing from any repo (ie. OL7 .iso)
- use db_load from container so we can drop Requires: compat-db43 since
  OL7 doesn't have this package
- adjust lxc.spec for move of libexecdir/lxc-init to sbin/lxc.init

* Mon Mar 31 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.2-2.0.1
- update to upstream 1.0.2
- include patch for yum update within container
- run ./autogen to ensure build env automake version is used since aclocal
  from upstream tarball may be too new

* Fri Mar 14 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.1-2.0.1
- update to upstream 1.0.1

* Thu Feb 20 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.0-2.0.1
- update to upstream 1.0.0
- update .spec file to align with upstream
- create /container on install if it doesn't already exist
- include Oracle template changes for OL7

* Wed Dec 18 2013 Dwight Engen <dwight.engen@oracle.com> - 1.0.0-0.1.beta1
- update to upstream lxc-1.0.0.alpha2

* Wed Oct 23 2013 Dwight Engen <dwight.engen@oracle.com> - 1.0.0-0.1.alpha2
- update to upstream lxc-1.0.0.alpha2
- fix rpm changelog entries to conform to packaging guidelines
- [Orabug 17190287] restrict writeability in /proc and /sys

* Tue Oct 22 2013 Dwight Engen <dwight.engen@oracle.com> - 1.0.0-0.1.alpha2
- fix some rpmlint warnings/errors
- split lua bits into seperate package

* Fri Jul 12 2013 Dwight Engen <dwight.engen@oracle.com> - 0.9.0-2.0.4
- [Orabug 16316936] fix sem_open(3) by mounting /dev/shm as tmpfs
- [Orabug 17042712] fix sshd template
- [Orabug 17066749] fix hostname in cloned containers

* Thu May  9 2013 Dwight Engen <dwight.engen@oracle.com> - 0.9.0-2.0.3
- applied upstream fixes
- oracle build environment for lxc now has newer kernel-headers, which makes
  lxc-attach now work since at build time the the setns syscall introduced
  in kernel 3.7 will be found

* Fri Apr 12 2013 Dwight Engen <dwight.engen@oracle.com> - 0.9.0-2.0.2
- applied upstream patches for other minor issues
- The sparc architecture doesn't have or need a compat-db4* requirement
  in the spec-file
- [Orabug 16656944] lxc-clone fails

* Mon Apr 08 2013 Dwight Engen <dwight.engen@oracle.com> - 0.9.0-2.0.1
- update to upstream 0.9.0
- lxc.spec: remove patches that have been upstreamed
- patch back to building docs with docbook-utils instead of docbook2X

* Tue Mar 12 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.9
- move .rpmdb on Debian host
- [Orabug 16327664] fix cosmetic error on ol5 cp resolv.conf
- [Orabug 16297950] silence cosmetic "cat /proc/self/attr/current" error

* Thu Feb 14 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.8
- [Orabug 16324116] handle 5.latest correctly in redo_pkgs
- [Orabug 16327382] commenting out of "Remounting rootfs" in rc.sysinit

* Wed Feb 13 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.7
- use libvirt for rpm Requires not libvirt-daemon

* Tue Feb 12 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.6
- [Orabug 16297177] default to same release as host
- [Orabug 16297404] add libvirt-daemon and compat-db43 as rpm Requires
- [Orabug 16297950] set selinux labels on devices created by oracle template
- [Orabug 16302675] don't attempt to remount / (superficial error message)
- [Orabug 16303282] don't attempt to unmount swap in container halt
- [Orabug 16304447] bad copy when using oracle templatefs -t option
- [Orabug 16316699] lxc-ls returning non-container directories

* Fri Feb 08 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.5
- merge all oracle template patches into one, update to latest to handle
  ol4 better and handle some selinux cases
- remove distro config /etc/lxc/lxc.conf patch since it is not needed and
  the name is changing in 0.9.0
- [Orabug 16296667] fix misapplied patch in lxc-shutdown

* Wed Jan 09 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.4
- [Orabug 16010534] prevent insmod, rmmod (git d378aebe)
- [Orabug 16071473] document <Ctrl-a q> to escape lxc-console (git 76848789)
- [Orabug 16090880] lxc-shutdown not working

* Fri Dec 28 2012 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.3
- fix creation of busybox based containers
- [Orabug 15984742] lxc-destroy only allowed in the STOPPED state
- [Orabug 15989848] lxc-wait hangs waiting for state FROZEN,FREEZING, or THAWED

* Fri Dec 14 2012 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.2
- fix use with OVM template rootfs
- add support for creating ol4 container from OVM template
- [Orabug 15984921], [Orabug 15972116] fix race/corruption with multiple
  lxc-start, lxc-execute

* Tue Dec  4 2012 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.1
- Add autoconf, automake to BuildRequires since patch0001 modifies configure.ac,
  and if the build files are not regenerated the Oracle template will not be
  included.

* Wed Nov 21 2012 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2
- include oracle template
- set container directory to /container

* Mon Sep 10 2012 Dwight Engen <dwight.engen@oracle.com> - 0.8.0
- fix lxc-init moved to libexec
- .pc moved to _libdir
- package template files /usr/share/lxc/templates

* Thu Sep  8 2011 Greg Kurz <gkurz@fr.ibm.com> - 0.7.5.1
- fix installed files for rpmbuild
- introduce lxc-libs package

* Fri Jul 23 2010 Daniel Lezcano <dlezcano@fr.ibm.com> - 0.7.2
- set attribute for installed files
- fix libraries installation

* Tue Mar 24 2009 Daniel Lezcano <daniel.lezcano@free.fr> - 0.6.1
- Removed capability setting, let the user to do that through "lxc-setcap"

* Mon Feb 16 2009 Daniel Lezcano <daniel.lezcano@free.fr> - 0.6.0
- Added more capabilities to the executables

* Sun Jan 25 2009 Daniel Lezcano <daniel.lezcano@free.fr> - 0.6.0
- Reduced spec file

* Sun Aug 3 2008 Daniel Lezcano <dlezcano@fr.ibm.com> - 0.1.0
- Initial RPM release.

# Local variables:
# mode: shell-script
# sh-shell: rpm
# end:
